# encoding: utf-8

from django import db
from django.db.models import get_models, signals
from django.conf import settings

import auf.django.coda.models

def post_syncdb(sender, **kwargs):
    """Création des vues vers coda."""

    # On ne crée des vues que si on est sur une BD MySQL.
    # L'attribut db.connection.vendor n'est présent qu'à partir de Django
    # 1.3
    if (hasattr(db.connection, 'vendor') and db.connection.vendor != 'mysql') or \
       'mysql' not in db.backend.__name__:
        return

    cursor = db.connection.cursor()

    # Vérifions qu'on a une BD qui s'appelle 'coda'
    if not cursor.execute("SHOW DATABASES LIKE 'coda'"):
        return

    # Déterminons la liste de tables de référence dans coda
    cursor.execute("SHOW TABLES IN coda LIKE 'coda\\_%%'")
    coda_tables = set(row[0] for row in cursor)

    # Déterminons la liste de tables que nous avons déjà et
    # enlevons-les des tables de coda
    cursor.execute("SHOW FULL TABLES WHERE Table_type != 'VIEW'")
    my_tables = set(row[0] for row in cursor)
    coda_tables.difference_update(my_tables)

    # On peut maintenant créer les vues
    cursor = db.connection.cursor()
    for table in coda_tables:
        print u"Création d'une vue vers coda.%s" % table
        cursor.execute(
            'CREATE OR REPLACE VIEW `%s` AS SELECT * FROM coda.`%s`' % (table, table)
        )

signals.post_syncdb.connect(post_syncdb, sender=auf.django.coda.models)
